<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fi_FI">
<context>
    <name>QvkAudioController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Valitse yksi tai useampi laite</translation>
    </message>
</context>
<context>
    <name>QvkAudioController_wl</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Valitse yksi tai useampi laite</translation>
    </message>
</context>
<context>
    <name>QvkCameraSingle</name>
    <message>
        <source>Remove window frame</source>
        <translation>Poista ikkunakehys</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Käännä pystysuunnassa</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Käännä vaakasuunnassa</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Käänteinen</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Harmaa</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Mustavalkoinen</translation>
    </message>
    <message>
        <source>Switch to Window</source>
        <translation>Vaihda ikkunaan</translation>
    </message>
    <message>
        <source>Switch to Fullscreen</source>
        <translation>Vaihda koko näyttöön</translation>
    </message>
</context>
<context>
    <name>QvkCameraWindow</name>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
</context>
<context>
    <name>QvkCiscoFinishDialog</name>
    <message>
        <source>The setup was successful.</source>
        <translation>Asennus onnistui.</translation>
    </message>
    <message>
        <source>Close this window and start vokoscreenNG again.</source>
        <translation>Sulje ikkuna ja käynnistä vokoscreenNG uudelleen.</translation>
    </message>
    <message>
        <source>Have fun with vokoscreenNG</source>
        <translation>Pidä hauskaa vokoscreenNG:n parissa</translation>
    </message>
</context>
<context>
    <name>QvkDirDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Valintaikkuna</translation>
    </message>
</context>
<context>
    <name>QvkHelp</name>
    <message>
        <source>Help</source>
        <translation>Ohje</translation>
    </message>
</context>
<context>
    <name>QvkImageFromTabs</name>
    <message>
        <source>No filemanager found.</source>
        <translation>Tiedostonhallintaa ei löytynyt.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Asenna tiedostonhallinta. </translation>
    </message>
</context>
<context>
    <name>QvkImageFromTabs_wl</name>
    <message>
        <source>No filemanager found.</source>
        <translation>Tiedostonhallintaa ei löytynyt.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Asenna tiedostonhallinta. </translation>
    </message>
</context>
<context>
    <name>QvkLimitDiskFreeSpace</name>
    <message>
        <source>Warning</source>
        <translation>Varoitus</translation>
    </message>
    <message>
        <source>The recording is not started, not enough free disk space.</source>
        <translation>Tallennusta ei käynnistetä, ei ole riittävästi vapaata levytilaa.</translation>
    </message>
    <message>
        <source>The free disk space limit is reached.</source>
        <translation>Vapaan levytilan raja on saavutettu.</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Vapaan levytilan raja</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megatavu</translation>
    </message>
    <message>
        <source>The recording was stopped, not enough free disk space.</source>
        <translation>Tallennus pysäytettiin, ei tarpeeksi vapaata levytilaa.</translation>
    </message>
</context>
<context>
    <name>QvkMainWindow</name>
    <message>
        <source>No filemanager found.</source>
        <extracomment>Display a MessageBox, if not found a filemanager.</extracomment>
        <translation>Tiedostonhallintaa ei löytynyt.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Asenna tiedostonhallinta. </translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Lähdekoodi</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Kotisivu</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Käännökset</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Lahjoita</translation>
    </message>
</context>
<context>
    <name>QvkMainWindow_wl</name>
    <message>
        <source>Sourcecode</source>
        <translation>Lähdekoodi</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Kotisivu</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Käännökset</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Lahjoita</translation>
    </message>
    <message>
        <source>No filemanager found.</source>
        <translation>Tiedostonhallintaa ei löytynyt.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Asenna tiedostonhallinta. </translation>
    </message>
</context>
<context>
    <name>QvkPulseAudioWatcher</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Valitse yksi tai useampi laite</translation>
    </message>
</context>
<context>
    <name>QvkPulseAudioWatcher_wl</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Valitse yksi tai useampi laite</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise</name>
    <message>
        <source>Area</source>
        <translation>Alue</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise_wl</name>
    <message>
        <source>Area</source>
        <translation>Alue</translation>
    </message>
</context>
<context>
    <name>QvkSnapshot</name>
    <message>
        <source>No filemanager found.</source>
        <translation>Tiedostonhallintaa ei löytynyt.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Asenna tiedostonhallinta. </translation>
    </message>
</context>
<context>
    <name>QvkSystray</name>
    <message>
        <source>Start</source>
        <translation>Aloita</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Lopeta</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Tauko</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Jatka</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Poistu</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Suurennus</translation>
    </message>
</context>
<context>
    <name>QvkSystrayAlternative</name>
    <message>
        <source>Start</source>
        <translation>Aloita</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Lopeta</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Tauko</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Jatka</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Poistu</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Suurennus</translation>
    </message>
</context>
<context>
    <name>QvkWASAPIController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Valitse yksi tai useampi laite</translation>
    </message>
</context>
<context>
    <name>cameraSettingsDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Valintaikkuna</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Käännä vaakasuunnassa</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Käännä pystysuunnassa</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Käänteinen</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Harmaa</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Mustavalkoinen</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Poista ikkunakehys</translation>
    </message>
    <message>
        <source>Camera settings</source>
        <translation>Kameran asetukset</translation>
    </message>
</context>
<context>
    <name>formMainWindow</name>
    <message>
        <source>Area</source>
        <translation>Alue</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Nollaa</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Suurennus</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Lähtölaskenta</translation>
    </message>
    <message>
        <source>Video size:</source>
        <translation>Videon koko:</translation>
    </message>
    <message>
        <source>Free disk space:</source>
        <translation>Vapaa levytila:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Tietoja</translation>
    </message>
    <message>
        <source>Record Time:</source>
        <translation>Tallennusaika:</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Ääni</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Ruutuja</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Videokoodekki</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Tallennusmuoto</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Audiokoodekki</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Älä tallenna hiiren osoitinta</translation>
    </message>
    <message>
        <source>Hour</source>
        <translation>Tunti</translation>
    </message>
    <message>
        <source>Minute</source>
        <translation>Minuutti</translation>
    </message>
    <message>
        <source>Start the timer</source>
        <translation>Käynnistä ajastin</translation>
    </message>
    <message>
        <source>Stop recording after</source>
        <translation>Pysäytä tallennus tämän jälkeen</translation>
    </message>
    <message>
        <source>Hours</source>
        <translation>Tuntia</translation>
    </message>
    <message>
        <source>Minutes</source>
        <translation>Minuuttia</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation>Sekuntia</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Videon polku</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Vapaan levytilan raja</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Näytä ilmoitusalueella</translation>
    </message>
    <message>
        <source>Second wait before recording</source>
        <translation>Sekuntia odotusta ennen tallennusta</translation>
    </message>
    <message>
        <source>Look for updates</source>
        <translation>Tarkista päivitykset</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Ohje</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Käytettävissä</translation>
    </message>
    <message>
        <source>Not available</source>
        <translation>Ei käytettävissä</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Aloita</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Lopeta</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Tauko</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Jatka</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Toista</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Kansio</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Käänteinen</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Harmaa</translation>
    </message>
    <message>
        <source>Play last record</source>
        <translation>Toista viimeisin tallennus</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Avaa kansio</translation>
    </message>
    <message>
        <source>Minimized when recording starts</source>
        <translation>Pienennä kun tallennus alkaa</translation>
    </message>
    <message>
        <source>Starts minimized</source>
        <translation>Käynnistä pienennettynä</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Käännä vaakasuunnassa</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Käännä pystysuunnassa</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Mustavalkoinen</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Poista ikkunakehys</translation>
    </message>
    <message>
        <source>Reset all settings at the next start</source>
        <translation>Nollaa kaikki asetukset seuraavalla käynnistyksellä</translation>
    </message>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Tekijänoikeudet ja lisenssit kuvista</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megatavu</translation>
    </message>
    <message>
        <source>Screencast</source>
        <translation>Näytön tallennin</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Toistin</translation>
    </message>
    <message>
        <source>Log</source>
        <translation>Loki</translation>
    </message>
    <message>
        <source>Automatically</source>
        <translation>Automaattisesti</translation>
    </message>
    <message>
        <source>Create images of tabs </source>
        <translation>Luo kuvat välilehdistä</translation>
    </message>
    <message>
        <source>License information</source>
        <translation>Lisenssitiedot</translation>
    </message>
    <message>
        <source>ON</source>
        <translation>ON</translation>
    </message>
    <message>
        <source>OFF</source>
        <translation>POIS</translation>
    </message>
    <message>
        <source>Global keyboard shortcuts</source>
        <translation>Yleiset pikanäppäimet</translation>
    </message>
    <message>
        <source>Assigned shortcut keys.</source>
        <translation>Määritetyt pikanäppäimet.</translation>
    </message>
    <message>
        <source>Keyboard shortcut not assigned or assigned more than once.</source>
        <translation>Pikanäppäintä ei ole määritetty tai määritetty useammin kuin kerran.</translation>
    </message>
    <message>
        <source>If it shows assigned but does not work, it is being used by another program.</source>
        <translation>Jos näyttää määritystä, mutta ei toimi, se on toisen ohjelman käytössä.</translation>
    </message>
    <message>
        <source>Snapshot</source>
        <translation>Valokuva</translation>
    </message>
    <message>
        <source>Imagepath</source>
        <translation>Kuvan polku</translation>
    </message>
    <message>
        <source>Hide this window</source>
        <translation>Piilota tämä ikkuna</translation>
    </message>
    <message>
        <source>Seconds wait before recording</source>
        <translation>Odotusaika ennen tallennusta</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Ikkuna</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Koko näyttö</translation>
    </message>
</context>
<context>
    <name>formMainWindow_wl</name>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Tekijänoikeudet ja lisenssit kuvista</translation>
    </message>
    <message>
        <source>Create images of tabs </source>
        <translation>Luo kuvat välilehdistä</translation>
    </message>
    <message>
        <source>License information</source>
        <translation>Lisenssitiedot</translation>
    </message>
    <message>
        <source>ON</source>
        <translation>ON</translation>
    </message>
    <message>
        <source>OFF</source>
        <translation>POIS</translation>
    </message>
    <message>
        <source>Record Time:</source>
        <translation>Tallennusaika:</translation>
    </message>
    <message>
        <source>Video size:</source>
        <translation>Videon koko:</translation>
    </message>
    <message>
        <source>Free disk space:</source>
        <translation>Vapaa levytila:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Tietoja</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Ikkuna</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Koko näyttö</translation>
    </message>
    <message>
        <source>Area</source>
        <translation>Alue</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Videokoodekki</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Ruutuja</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Tallennusmuoto</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Käytettävissä</translation>
    </message>
    <message>
        <source>Not available</source>
        <translation>Ei käytettävissä</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Aloita</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Lopeta</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Kansio</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Älä tallenna hiiren osoitinta</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Audiokoodekki</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Videon polku</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Lähtölaskenta</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Ohje</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Käänteinen</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Harmaa</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Mustavalkoinen</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Käännä pystysuunnassa</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Käännä vaakasuunnassa</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Poista ikkunakehys</translation>
    </message>
    <message>
        <source>Second wait before recording</source>
        <translation>Sekuntia odotusta ennen tallennusta</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Nollaa</translation>
    </message>
    <message>
        <source>Hide this window</source>
        <translation>Piilota tämä ikkuna</translation>
    </message>
    <message>
        <source>Seconds wait before recording</source>
        <translation>Odotusaika ennen tallennusta</translation>
    </message>
</context>
<context>
    <name>license</name>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Tekijänoikeudet ja lisenssit kuvista</translation>
    </message>
</context>
<context>
    <name>playerGST</name>
    <message>
        <source>Play</source>
        <translation>Toista</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Tauko</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Lopeta</translation>
    </message>
</context>
</TS>